@@ -1,28 +1,36 @@
-/***************************************************************************
- *   Copyright (C) 2019 by Mark Nauwelaerts <mark.nauwelaerts@gmail.com>   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*  SPDX-License-Identifier: MIT
+
+    Copyright (C) 2019 Mark Nauwelaerts <mark.nauwelaerts@gmail.com>
+
+    Permission is hereby granted, free of charge, to any person obtaining
+    a copy of this software and associated documentation files (the
+    "Software"), to deal in the Software without restriction, including
+    without limitation the rights to use, copy, modify, merge, publish,
+    distribute, sublicense, and/or sell copies of the Software, and to
+    permit persons to whom the Software is furnished to do so, subject to
+    the following conditions:
+
+    The above copyright notice and this permission notice shall be included
+    in all copies or substantial portions of the Software.
+
+    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+*/
 
 #ifndef LSPCLIENTPROTOCOL_H
 #define LSPCLIENTPROTOCOL_H
 
+#include <QHash>
+#include <QJsonArray>
+#include <QJsonObject>
+#include <QList>
 #include <QString>
 #include <QUrl>
-#include <QList>
 #include <QVector>
 
 #include <KTextEditor/Cursor>
@@ -33,8 +41,7 @@
 // Moreover, to avoid introducing a custom 'optional' type, absence of an optional
 // part/member is usually signalled by some 'invalid' marker (empty, negative).
 
-enum class LSPErrorCode
-{
+enum class LSPErrorCode {
     // Defined by JSON RPC
     ParseError = -32700,
     InvalidRequest = -32600,
@@ -51,28 +58,24 @@ enum class LSPErrorCode
     ContentModified = -32801
 };
 
-enum class LSPDocumentSyncKind
-{
-    None = 0,
-    Full = 1,
-    Incremental = 2
-};
+enum class LSPDocumentSyncKind { None = 0, Full = 1, Incremental = 2 };
 
-struct LSPCompletionOptions
-{
+struct LSPCompletionOptions {
     bool provider = false;
     bool resolveProvider = false;
     QVector<QChar> triggerCharacters;
 };
 
-struct LSPSignatureHelpOptions
-{
+struct LSPSignatureHelpOptions {
     bool provider = false;
     QVector<QChar> triggerCharacters;
 };
 
-struct LSPServerCapabilities
-{
+// ensure distinct type
+struct LSPDocumentOnTypeFormattingOptions : public LSPSignatureHelpOptions {
+};
+
+struct LSPServerCapabilities {
     LSPDocumentSyncKind textDocumentSync = LSPDocumentSyncKind::None;
     bool hoverProvider = false;
     LSPCompletionOptions completionProvider;
@@ -83,17 +86,17 @@ struct LSPServerCapabilities
     bool referencesProvider = false;
     bool documentSymbolProvider = false;
     bool documentHighlightProvider = false;
+    bool documentFormattingProvider = false;
+    bool documentRangeFormattingProvider = false;
+    LSPDocumentOnTypeFormattingOptions documentOnTypeFormattingProvider;
+    bool renameProvider = false;
+    // CodeActionOptions not useful/considered at present
+    bool codeActionProvider = false;
 };
 
-enum class LSPMarkupKind
-{
-    None = 0,
-    PlainText = 1,
-    MarkDown = 2
-};
+enum class LSPMarkupKind { None = 0, PlainText = 1, MarkDown = 2 };
 
-struct LSPMarkupContent
-{
+struct LSPMarkupContent {
     LSPMarkupKind kind = LSPMarkupKind::None;
     QString value;
 };
@@ -112,28 +115,28 @@ using LSPPosition = KTextEditor::Cursor;
  */
 using LSPRange = KTextEditor::Range;
 
-struct LSPLocation
-{
+struct LSPLocation {
     QUrl uri;
     LSPRange range;
 };
 
-enum class LSPDocumentHighlightKind
-{
-    Text = 1,
-    Read = 2,
-    Write = 3
+struct LSPTextDocumentContentChangeEvent {
+    LSPRange range;
+    QString text;
 };
 
-struct LSPDocumentHighlight
-{
+enum class LSPDocumentHighlightKind { Text = 1, Read = 2, Write = 3 };
+
+struct LSPDocumentHighlight {
     LSPRange range;
     LSPDocumentHighlightKind kind;
 };
 
-struct LSPHover
-{
-    LSPMarkupContent contents;
+struct LSPHover {
+    // vector for contents to support all three variants:
+    // MarkedString | MarkedString[] | MarkupContent
+    // vector variant is still in use e.g. by Rust rls
+    QVector<LSPMarkupContent> contents;
     LSPRange range;
 };
 
@@ -158,12 +161,14 @@ enum class LSPSymbolKind {
     Array = 18,
 };
 
-struct LSPSymbolInformation
-{
-    LSPSymbolInformation(const QString & _name, LSPSymbolKind _kind,
-                         LSPRange _range, const QString & _detail = QString())
-        : name(_name), detail(_detail), kind(_kind), range(_range)
-    {}
+struct LSPSymbolInformation {
+    LSPSymbolInformation(const QString &_name, LSPSymbolKind _kind, LSPRange _range, const QString &_detail)
+        : name(_name)
+        , detail(_detail)
+        , kind(_kind)
+        , range(_range)
+    {
+    }
     QString name;
     QString detail;
     LSPSymbolKind kind;
@@ -171,8 +176,7 @@ struct LSPSymbolInformation
     QList<LSPSymbolInformation> children;
 };
 
-enum class LSPCompletionItemKind
-{
+enum class LSPCompletionItemKind {
     Text = 1,
     Method = 2,
     Function = 3,
@@ -200,8 +204,7 @@ enum class LSPCompletionItemKind
     TypeParameter = 25,
 };
 
-struct LSPCompletionItem
-{
+struct LSPCompletionItem {
     QString label;
     LSPCompletionItemKind kind;
     QString detail;
@@ -210,30 +213,38 @@ struct LSPCompletionItem
     QString insertText;
 };
 
-struct LSPParameterInformation
-{
+struct LSPParameterInformation {
     // offsets into overall signature label
     // (-1 if invalid)
     int start;
     int end;
 };
 
-struct LSPSignatureInformation
-{
+struct LSPSignatureInformation {
     QString label;
     LSPMarkupContent documentation;
     QList<LSPParameterInformation> parameters;
 };
 
-struct LSPSignatureHelp
-{
+struct LSPSignatureHelp {
     QList<LSPSignatureInformation> signatures;
     int activeSignature;
     int activeParameter;
 };
 
-enum class LSPDiagnosticSeverity
-{
+struct LSPFormattingOptions {
+    int tabSize;
+    bool insertSpaces;
+    // additional fields
+    QJsonObject extra;
+};
+
+struct LSPTextEdit {
+    LSPRange range;
+    QString newText;
+};
+
+enum class LSPDiagnosticSeverity {
     Unknown = 0,
     Error = 1,
     Warning = 2,
@@ -241,27 +252,54 @@ enum class LSPDiagnosticSeverity
     Hint = 4,
 };
 
-struct LSPDiagnosticRelatedInformation
-{
+struct LSPDiagnosticRelatedInformation {
     // empty url / invalid range when absent
     LSPLocation location;
     QString message;
 };
 
-struct LSPDiagnostics
-{
+struct LSPDiagnostic {
     LSPRange range;
     LSPDiagnosticSeverity severity;
     QString code;
     QString source;
     QString message;
-    LSPDiagnosticRelatedInformation relatedInformation;
+    QList<LSPDiagnosticRelatedInformation> relatedInformation;
 };
 
-struct LSPPublishDiagnosticsParams
-{
+struct LSPPublishDiagnosticsParams {
     QUrl uri;
-    QList<LSPDiagnostics> diagnostics;
+    QList<LSPDiagnostic> diagnostics;
+};
+
+struct LSPCommand {
+    QString title;
+    QString command;
+    // pretty opaque
+    QJsonArray arguments;
+};
+
+struct LSPWorkspaceEdit {
+    // supported part for now
+    QHash<QUrl, QList<LSPTextEdit>> changes;
+};
+
+struct LSPCodeAction {
+    QString title;
+    QString kind;
+    QList<LSPDiagnostic> diagnostics;
+    LSPWorkspaceEdit edit;
+    LSPCommand command;
+};
+
+struct LSPApplyWorkspaceEditParams {
+    QString label;
+    LSPWorkspaceEdit edit;
+};
+
+struct LSPApplyWorkspaceEditResponse {
+    bool applied;
+    QString failureReason;
 };
 
 #endif
