@@ -21,9 +21,9 @@
 #include "kateprojectinfoviewterminal.h"
 #include "kateprojectpluginview.h"
 
-#include <klocalizedstring.h>
-#include <kde_terminal_interface.h>
 #include <KPluginLoader>
+#include <kde_terminal_interface.h>
+#include <klocalizedstring.h>
 
 KPluginFactory *KateProjectInfoViewTerminal::s_pluginFactory = nullptr;
 
@@ -110,8 +110,7 @@ void KateProjectInfoViewTerminal::loadTerminal()
      * guard destruction, create new terminal!
      */
     connect(m_konsolePart, &KParts::ReadOnlyPart::destroyed, this, &KateProjectInfoViewTerminal::loadTerminal);
-    connect(m_konsolePart, SIGNAL(overrideShortcut(QKeyEvent *, bool &)),
-            this, SLOT(overrideShortcut(QKeyEvent *, bool &)));
+    connect(m_konsolePart, SIGNAL(overrideShortcut(QKeyEvent *, bool &)), this, SLOT(overrideShortcut(QKeyEvent *, bool &)));
 }
 
 void KateProjectInfoViewTerminal::overrideShortcut(QKeyEvent *, bool &override)
@@ -121,4 +120,3 @@ void KateProjectInfoViewTerminal::overrideShortcut(QKeyEvent *, bool &override)
      */
     override = true;
 }
-
