@@ -21,13 +21,13 @@
 #ifndef _KATE_PROJECT_PLUGIN_VIEW_H_
 #define _KATE_PROJECT_PLUGIN_VIEW_H_
 
-#include "kateprojectplugin.h"
 #include "kateproject.h"
-#include "kateprojectview.h"
 #include "kateprojectinfoview.h"
+#include "kateprojectplugin.h"
+#include "kateprojectview.h"
 
-#include <QPointer>
 #include <QComboBox>
+#include <QPointer>
 #include <QStackedWidget>
 #include <QToolButton>
 
@@ -97,10 +97,20 @@ public:
      * the main window we belong to
      * @return our main window
      */
-    KTextEditor::MainWindow *mainWindow() const {
+    KTextEditor::MainWindow *mainWindow() const
+    {
         return m_mainWindow;
     }
 
+    /**
+     * the plugin we belong to
+     * @return our plugin
+     */
+    KateProjectPlugin *plugin() const
+    {
+        return m_plugin;
+    }
+
 public Q_SLOTS:
     /**
      * Create views for given project.
@@ -111,6 +121,11 @@ public Q_SLOTS:
     QPair<KateProjectView *, KateProjectInfoView *> viewForProject(KateProject *project);
 
 private Q_SLOTS:
+    /**
+     * Plugin config updated
+     */
+    void slotConfigUpdated();
+
     /**
      * New view got created, we need to update our connections
      * @param view new created view
@@ -144,6 +159,11 @@ private Q_SLOTS:
      */
     void slotProjectIndex();
 
+    /**
+     * Goto current word
+     */
+    void slotGotoSymbol();
+
 Q_SIGNALS:
     /**
      * Emitted if projectFileName changed.
@@ -161,6 +181,12 @@ Q_SIGNALS:
      */
     void projectLookupWord(const QString &word);
 
+    /**
+     * Emitted when a ctags goto sysmbol is requested
+     * @param word lookup word
+     */
+    void gotoSymbol(const QString &word, int &results);
+
 private Q_SLOTS:
     /**
      * This slot is called whenever the active view changes in our main window.
@@ -210,6 +236,11 @@ private:
      */
     QWidget *m_toolInfoView;
 
+    /**
+     * our cross-projects toolview
+     */
+    QWidget *m_toolMultiView;
+
     /**
      * combo box with all loaded projects inside
      */
@@ -233,7 +264,7 @@ private:
     /**
      * project => view
      */
-    QMap<KateProject *, QPair<KateProjectView *, KateProjectInfoView *> > m_project2View;
+    QMap<KateProject *, QPair<KateProjectView *, KateProjectInfoView *>> m_project2View;
 
     /**
      * remember current active view text editor view
@@ -250,7 +281,12 @@ private:
      * lookup action
      */
     QAction *m_lookupAction;
+
+    /**
+     * goto symbol action
+     */
+    QAction *m_gotoSymbolAction;
+    QAction *m_gotoSymbolActionAppMenu;
 };
 
 #endif
-
