@@ -1,24 +1,22 @@
-/* This file is part of the KDE project
- *
- *  Copyright (C) 2005 Christoph Cullmann <cullmann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include "config.h"
+    Copyright (C) 2005 Christoph Cullmann <cullmann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "katesessionmanager.h"
 
@@ -29,13 +27,13 @@
 #include "katerunninginstanceinfo.h"
 
 #include <KConfigGroup>
-#include <KSharedConfig>
-#include <KLocalizedString>
-#include <KMessageBox>
-#include <KIO/CopyJob>
 #include <KDesktopFile>
 #include <KDirWatch>
+#include <KIO/CopyJob>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KService>
+#include <KSharedConfig>
 #include <KShell>
 
 #include <QApplication>
@@ -49,7 +47,7 @@
 #include <unistd.h>
 #endif
 
-//BEGIN KateSessionManager
+// BEGIN KateSessionManager
 
 KateSessionManager::KateSessionManager(QObject *parent, const QString &sessionsDir)
     : QObject(parent)
@@ -94,7 +92,7 @@ void KateSessionManager::updateSessionList()
     bool changed = false;
 
     // Add new sessions to our list
-    for (const QString session : qAsConst(list)) {
+    for (const QString &session : qAsConst(list)) {
         if (!m_sessions.contains(session)) {
             const QString file = sessionFileForName(session);
             m_sessions.insert(session, KateSession::create(file, session));
@@ -102,7 +100,7 @@ void KateSessionManager::updateSessionList()
         }
     }
     // Remove gone sessions from our list
-    for (const QString session : m_sessions.keys()) {
+    for (const QString &session : m_sessions.keys()) {
         if ((list.indexOf(session) < 0) && (m_sessions.value(session) != activeSession())) {
             m_sessions.remove(session);
             changed = true;
@@ -114,16 +112,14 @@ void KateSessionManager::updateSessionList()
     }
 }
 
-bool KateSessionManager::activateSession(KateSession::Ptr session,
-        const bool closeAndSaveLast,
-        const bool loadNew)
+bool KateSessionManager::activateSession(KateSession::Ptr session, const bool closeAndSaveLast, const bool loadNew)
 {
     if (activeSession() == session) {
         return true;
     }
 
     if (!session->isAnonymous()) {
-        //check if the requested session is already open in another instance
+        // check if the requested session is already open in another instance
         KateRunningInstanceMap instances;
         if (!fillinRunningKateAppInstances(&instances)) {
             KMessageBox::error(nullptr, i18n("Internal error: there is more than one instance open for a given session."));
@@ -131,8 +127,12 @@ bool KateSessionManager::activateSession(KateSession::Ptr session,
         }
 
         if (instances.contains(session->name())) {
-            if (KMessageBox::questionYesNo(nullptr, i18n("Session '%1' is already opened in another kate instance, change there instead of reopening?", session->name()),
-                                           QString(), KStandardGuiItem::yes(), KStandardGuiItem::no(), QStringLiteral("katesessionmanager_switch_instance")) == KMessageBox::Yes) {
+            if (KMessageBox::questionYesNo(nullptr,
+                                           i18n("Session '%1' is already opened in another kate instance, change there instead of reopening?", session->name()),
+                                           QString(),
+                                           KStandardGuiItem::yes(),
+                                           KStandardGuiItem::no(),
+                                           QStringLiteral("katesessionmanager_switch_instance")) == KMessageBox::Yes) {
                 instances[session->name()]->dbus_if->call(QStringLiteral("activate"));
                 cleanupRunningKateAppInstanceMap(&instances);
                 return false;
@@ -192,7 +192,7 @@ void KateSessionManager::loadSession(const KateSession::Ptr &session) const
     KConfig *cfg = sc;
     bool delete_cfg = false;
     // a new, named session, read settings of the default session.
-    if (! sc->hasGroup("Open MainWindows")) {
+    if (!sc->hasGroup("Open MainWindows")) {
         delete_cfg = true;
         cfg = new KConfig(anonymousSessionFile(), KConfig::SimpleConfig);
     }
@@ -316,9 +316,7 @@ QString KateSessionManager::renameSession(KateSession::Ptr session, const QStrin
     KIO::CopyJob *job = KIO::move(srcUrl, dstUrl, KIO::HideProgressInfo);
 
     if (!job->exec()) {
-        KMessageBox::sorry(QApplication::activeWindow(),
-                           i18n("The session could not be renamed to \"%1\". Failed to write to \"%2\"", newName, newFile),
-                           i18n("Session Renaming"));
+        KMessageBox::sorry(QApplication::activeWindow(), i18n("The session could not be renamed to \"%1\". Failed to write to \"%2\"", newName, newFile), i18n("Session Renaming"));
         return QString();
     }
 
@@ -339,7 +337,7 @@ QString KateSessionManager::renameSession(KateSession::Ptr session, const QStrin
 void KateSessionManager::saveSessionTo(KConfig *sc) const
 {
     // Clear the session file to avoid to accumulate outdated entries
-    for (auto group : sc->groupList()) {
+    for (const auto &group : sc->groupList()) {
         sc->deleteGroup(group);
     }
 
@@ -407,12 +405,12 @@ bool KateSessionManager::chooseSession()
     const QString sesStart(c.readEntry("Startup Session", "manual"));
 
     // uhh, just open last used session, show no chooser
-    if (sesStart == QStringLiteral("last")) {
+    if (sesStart == QLatin1String("last")) {
         return activateSession(lastSession, false);
     }
 
     // start with empty new session or in case no sessions exist
-    if (sesStart == QStringLiteral("new") || sessionList().size() == 0) {
+    if (sesStart == QLatin1String("new") || sessionList().empty()) {
         return activateAnonymousSession();
     }
 
@@ -458,8 +456,9 @@ QString KateSessionManager::askForNewSessionName(KateSession::Ptr session, const
     }
 
     const QString messagePrompt = i18n("Session name:");
-    const KLocalizedString messageExist = ki18n("There is already an existing session with your chosen name: %1\n"
-                                                "Please choose a different one.");
+    const KLocalizedString messageExist = ki18n(
+        "There is already an existing session with your chosen name: %1\n"
+        "Please choose a different one.");
     const QString messageEmpty = i18n("To save a session, you must specify a name.");
 
     QString messageTotal = messagePrompt;
@@ -470,7 +469,7 @@ QString KateSessionManager::askForNewSessionName(KateSession::Ptr session, const
 
         if (name.isEmpty()) {
             preset = suggestNewSessionName(session->name());
-            messageTotal = messageEmpty + QStringLiteral("\n\n") + messagePrompt;
+            messageTotal = messageEmpty + QLatin1String("\n\n") + messagePrompt;
 
         } else if (QFile::exists(sessionFileForName(name))) {
             preset = suggestNewSessionName(name);
@@ -478,7 +477,7 @@ QString KateSessionManager::askForNewSessionName(KateSession::Ptr session, const
                 // Very unlikely, but as fall back we keep users input
                 preset = name;
             }
-            messageTotal = messageExist.subs(name).toString() + QStringLiteral("\n\n") + messagePrompt;
+            messageTotal = messageExist.subs(name).toString() + QLatin1String("\n\n") + messagePrompt;
 
         } else {
             return name;
@@ -493,7 +492,7 @@ QString KateSessionManager::askForNewSessionName(KateSession::Ptr session, const
         }
         dlg.setLabelText(messageTotal);
         dlg.setTextValue(preset);
-        dlg.resize(900,100);  // FIXME Calc somehow a proper size
+        dlg.resize(900, 100); // FIXME Calc somehow a proper size
         bool ok = dlg.exec();
         name = dlg.textValue();
 
@@ -529,7 +528,6 @@ void KateSessionManager::sessionManage()
     QScopedPointer<KateSessionManageDialog>(new KateSessionManageDialog(KateApp::self()->activeKateMainWindow()))->exec();
 }
 
-
 bool KateSessionManager::sessionIsActive(const QString &session)
 {
     // Try to avoid unneed action
@@ -550,7 +548,7 @@ bool KateSessionManager::sessionIsActive(const QString &session)
     }
 
     for (const QString &s : qAsConst(services)) {
-        if (!s.startsWith(QStringLiteral("org.kde.kate-"))) {
+        if (!s.startsWith(QLatin1String("org.kde.kate-"))) {
             continue;
         }
 
@@ -563,7 +561,6 @@ bool KateSessionManager::sessionIsActive(const QString &session)
     return false;
 }
 
-
 QString KateSessionManager::anonymousSessionFile() const
 {
     const QString file = m_sessionsDir + QStringLiteral("/../anonymous.katesession");
@@ -595,9 +592,7 @@ void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
     QStringList newActions = df->readActions();
 
     // try to keep existing custom actions intact, only remove our "Session" actions and add them back later
-    newActions.erase(std::remove_if(newActions.begin(), newActions.end(), [](const QString &action) {
-        return action.startsWith(QLatin1String("Session "));
-    }), newActions.end());
+    newActions.erase(std::remove_if(newActions.begin(), newActions.end(), [](const QString &action) { return action.startsWith(QLatin1String("Session ")); }), newActions.end());
 
     // Limit the number of list entries we like to offer
     const int maxEntryCount = std::min(sessionList.count(), 10);
@@ -612,8 +607,7 @@ void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
     sessionActions.reserve(maxEntryCount);
 
     for (int i = 0; i < maxEntryCount; ++i) {
-        sessionActions << QStringLiteral("Session %1").arg(QString::fromLatin1(QCryptographicHash::hash(sessionSubList.at(i).toUtf8()
-                                                                             , QCryptographicHash::Md5).toHex()));
+        sessionActions << QStringLiteral("Session %1").arg(QString::fromLatin1(QCryptographicHash::hash(sessionSubList.at(i).toUtf8(), QCryptographicHash::Md5).toHex()));
     }
 
     newActions += sessionActions;
@@ -649,5 +643,4 @@ void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
 #endif
 }
 
-//END KateSessionManager
-
+// END KateSessionManager
